PluginData

Enum PluginData 

pub enum PluginData<'a> {
    Hash {
        title: &'a str,
        items: HashMap<&'a str, &'a str>,
    },
    List {
        title: &'a str,
        items: Vec<(&'a str, &'a str, &'a str)>,
    },
    String {
        title: &'a str,
        content_type: StringContentType,
        content: &'a str,
    },
    Table {
        title: &'a str,
        num_columns: usize,
        rows: Vec<Vec<&'a str>>,
    },
}
Models a datum that can be attached to an object.

Variants



Hash

Fields

title: &'a str
items: HashMap<&'a str, &'a str>


List

Fields

title: &'a str
items: Vec<(&'a str, &'a str, &'a str)>


String

Fields

title: &'a str
content_type: StringContentType
content: &'a str


Table

Fields

title: &'a str
num_columns: usize
rows: Vec<Vec<&'a str>>

Implementations

Source

impl<'a> PluginData<'a>

pub fn add_as_args(&'a self, cmd: &mut Cmd)

Adds the necessary args to a redis command in order to complete a plugin data creation fcall with this data.