NetdoxWriter

Trait NetdoxWriter 

pub trait NetdoxWriter {
    // Required methods
    fn put_dns(
        &mut self,
        plugin: &str,
        name: &str,
        rtype: Option<&str>,
        value: Option<&str>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_dns_plugin_data<'a>(
        &mut self,
        plugin: &str,
        name: &str,
        pdata_id: &str,
        data: PluginData<'a>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_dns_metadata(
        &mut self,
        plugin: &str,
        name: &str,
        metadata: &HashMap<&str, &str>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_node(
        &mut self,
        plugin: &str,
        name: &str,
        dns_names: Vec<&str>,
        exclusive: bool,
        link_id: Option<&str>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_node_plugin_data<'a>(
        &mut self,
        plugin: &str,
        dns_names: Vec<&str>,
        pdata_id: &str,
        data: PluginData<'a>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_proc_node_plugin_data<'a>(
        &mut self,
        plugin: &str,
        link_id: &str,
        pdata_id: &str,
        data: PluginData<'a>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_node_metadata(
        &mut self,
        plugin: &str,
        dns_names: Vec<&str>,
        metadata: &HashMap<&str, &str>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_proc_node_metadata(
        &mut self,
        plugin: &str,
        link_id: &str,
        metadata: &HashMap<&str, &str>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_report(
        &mut self,
        plugin: &str,
        report_id: &str,
        title: &str,
        length: usize,
    ) -> impl Future<Output = FCallResult<()>> + Send;
    fn put_report_data<'a>(
        &mut self,
        plugin: &str,
        report_id: &str,
        index: usize,
        data: PluginData<'a>,
    ) -> impl Future<Output = FCallResult<()>> + Send;
}
Defines the write API.

Required Methods

fn put_dns( &mut self, plugin: &str, name: &str, rtype: Option<&str>, value: Option<&str>, ) -> impl Future<Output = FCallResult<()>> + Send

Create a DNS name and optionally attach a record.

fn put_dns_plugin_data<'a>( &mut self, plugin: &str, name: &str, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach plugin data to a DNS name.

fn put_dns_metadata( &mut self, plugin: &str, name: &str, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach metadata to a DNS name.

fn put_node( &mut self, plugin: &str, name: &str, dns_names: Vec<&str>, exclusive: bool, link_id: Option<&str>, ) -> impl Future<Output = FCallResult<()>> + Send

Create a node.

fn put_node_plugin_data<'a>( &mut self, plugin: &str, dns_names: Vec<&str>, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach plugin data to a node.

fn put_proc_node_plugin_data<'a>( &mut self, plugin: &str, link_id: &str, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach plugin data to a processed node by link ID.

fn put_node_metadata( &mut self, plugin: &str, dns_names: Vec<&str>, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach metadata to a node.

fn put_proc_node_metadata( &mut self, plugin: &str, link_id: &str, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach metadata to a processed node by link ID.

fn put_report( &mut self, plugin: &str, report_id: &str, title: &str, length: usize, ) -> impl Future<Output = FCallResult<()>> + Send

Create a report.

fn put_report_data<'a>( &mut self, plugin: &str, report_id: &str, index: usize, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send

Attach data to a report.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl NetdoxWriter for MultiplexedConnection

Source

async fn put_dns( &mut self, plugin: &str, name: &str, rtype: Option<&str>, value: Option<&str>, ) -> FCallResult<()>

Source

async fn put_dns_plugin_data<'a>( &mut self, plugin: &str, name: &str, pdata_id: &str, data: PluginData<'a>, ) -> FCallResult<()>

Source

async fn put_dns_metadata( &mut self, plugin: &str, name: &str, metadata: &HashMap<&str, &str>, ) -> FCallResult<()>

Source

async fn put_node( &mut self, plugin: &str, name: &str, dns_names: Vec<&str>, exclusive: bool, link_id: Option<&str>, ) -> FCallResult<()>

Source

async fn put_node_plugin_data<'a>( &mut self, plugin: &str, dns_names: Vec<&str>, pdata_id: &str, data: PluginData<'a>, ) -> FCallResult<()>

Source

async fn put_proc_node_plugin_data<'a>( &mut self, plugin: &str, link_id: &str, pdata_id: &str, data: PluginData<'a>, ) -> FCallResult<()>

Source

async fn put_node_metadata( &mut self, plugin: &str, dns_names: Vec<&str>, metadata: &HashMap<&str, &str>, ) -> FCallResult<()>

Source

async fn put_proc_node_metadata( &mut self, plugin: &str, link_id: &str, metadata: &HashMap<&str, &str>, ) -> FCallResult<()>

Source

async fn put_report( &mut self, plugin: &str, report_id: &str, title: &str, length: usize, ) -> FCallResult<()>

Source

async fn put_report_data<'a>( &mut self, plugin: &str, report_id: &str, index: usize, data: PluginData<'a>, ) -> FCallResult<()>

Implementors