pub trait NetdoxWriter {
// Required methods
fn put_dns(
&mut self,
plugin: &str,
name: &str,
rtype: Option<&str>,
value: Option<&str>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_dns_plugin_data<'a>(
&mut self,
plugin: &str,
name: &str,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_dns_metadata(
&mut self,
plugin: &str,
name: &str,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_node(
&mut self,
plugin: &str,
name: &str,
dns_names: Vec<&str>,
exclusive: bool,
link_id: Option<&str>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_node_plugin_data<'a>(
&mut self,
plugin: &str,
dns_names: Vec<&str>,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_proc_node_plugin_data<'a>(
&mut self,
plugin: &str,
link_id: &str,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_node_metadata(
&mut self,
plugin: &str,
dns_names: Vec<&str>,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_proc_node_metadata(
&mut self,
plugin: &str,
link_id: &str,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_report(
&mut self,
plugin: &str,
report_id: &str,
title: &str,
length: usize,
) -> impl Future<Output = FCallResult<()>> + Send;
fn put_report_data<'a>(
&mut self,
plugin: &str,
report_id: &str,
index: usize,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send;
}Expand description
Defines the write API.
Required Methods
Sourcefn put_dns(
&mut self,
plugin: &str,
name: &str,
rtype: Option<&str>,
value: Option<&str>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_dns( &mut self, plugin: &str, name: &str, rtype: Option<&str>, value: Option<&str>, ) -> impl Future<Output = FCallResult<()>> + Send
Create a DNS name and optionally attach a record.
Sourcefn put_dns_plugin_data<'a>(
&mut self,
plugin: &str,
name: &str,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_dns_plugin_data<'a>( &mut self, plugin: &str, name: &str, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach plugin data to a DNS name.
Sourcefn put_dns_metadata(
&mut self,
plugin: &str,
name: &str,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_dns_metadata( &mut self, plugin: &str, name: &str, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach metadata to a DNS name.
Sourcefn put_node(
&mut self,
plugin: &str,
name: &str,
dns_names: Vec<&str>,
exclusive: bool,
link_id: Option<&str>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_node( &mut self, plugin: &str, name: &str, dns_names: Vec<&str>, exclusive: bool, link_id: Option<&str>, ) -> impl Future<Output = FCallResult<()>> + Send
Create a node.
Sourcefn put_node_plugin_data<'a>(
&mut self,
plugin: &str,
dns_names: Vec<&str>,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_node_plugin_data<'a>( &mut self, plugin: &str, dns_names: Vec<&str>, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach plugin data to a node.
Sourcefn put_proc_node_plugin_data<'a>(
&mut self,
plugin: &str,
link_id: &str,
pdata_id: &str,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_proc_node_plugin_data<'a>( &mut self, plugin: &str, link_id: &str, pdata_id: &str, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach plugin data to a processed node by link ID.
Sourcefn put_node_metadata(
&mut self,
plugin: &str,
dns_names: Vec<&str>,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_node_metadata( &mut self, plugin: &str, dns_names: Vec<&str>, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach metadata to a node.
Sourcefn put_proc_node_metadata(
&mut self,
plugin: &str,
link_id: &str,
metadata: &HashMap<&str, &str>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_proc_node_metadata( &mut self, plugin: &str, link_id: &str, metadata: &HashMap<&str, &str>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach metadata to a processed node by link ID.
Sourcefn put_report(
&mut self,
plugin: &str,
report_id: &str,
title: &str,
length: usize,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_report( &mut self, plugin: &str, report_id: &str, title: &str, length: usize, ) -> impl Future<Output = FCallResult<()>> + Send
Create a report.
Sourcefn put_report_data<'a>(
&mut self,
plugin: &str,
report_id: &str,
index: usize,
data: PluginData<'a>,
) -> impl Future<Output = FCallResult<()>> + Send
fn put_report_data<'a>( &mut self, plugin: &str, report_id: &str, index: usize, data: PluginData<'a>, ) -> impl Future<Output = FCallResult<()>> + Send
Attach data to a report.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.